pub struct DefaultMetricsCallbackProvider {}Trait Implementations
Sourceimpl Clone for DefaultMetricsCallbackProvider
impl Clone for DefaultMetricsCallbackProvider
Sourcefn clone(&self) -> DefaultMetricsCallbackProvider
fn clone(&self) -> DefaultMetricsCallbackProvider
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for DefaultMetricsCallbackProvider
impl Default for DefaultMetricsCallbackProvider
Sourcefn default() -> DefaultMetricsCallbackProvider
fn default() -> DefaultMetricsCallbackProvider
Returns the “default value” for a type. Read more
Sourceimpl MetricsCallbackProvider for DefaultMetricsCallbackProvider
impl MetricsCallbackProvider for DefaultMetricsCallbackProvider
Sourcefn on_request(&self, _path: String)
fn on_request(&self, _path: String)
Method will be called when a request has been received.
path: the endpoint uri pathSourcefn on_response(
&self,
_path: String,
_latency: Duration,
_status: u16,
_grpc_status_code: Code,
)
fn on_response( &self, _path: String, _latency: Duration, _status: u16, _grpc_status_code: Code, )
Method to be called from the server when a request is performed.
path: the endpoint uri path
latency: the time when the request was received and when the response
was created status: the http status code of the response
grpc_status_code: the grpc status code (see https://github.com/grpc/grpc/blob/master/doc/statuscodes.md#status-codes-and-their-use-in-grpc)Sourcefn on_error(&self, _latency: Duration, _grpc_status_code: Code)
fn on_error(&self, _latency: Duration, _grpc_status_code: Code)
Called when a gRPC request fails at the transport/middleware level
(e.g. service panic, connection drop, timeout). gRPC application
errors (non-OK status codes) are NOT reported here — they are
already captured by
on_response.
The method path is not available at this layer (tower-http’s
on_failure callback does not receive the response object).Auto Trait Implementations
impl Freeze for DefaultMetricsCallbackProvider
impl RefUnwindSafe for DefaultMetricsCallbackProvider
impl Send for DefaultMetricsCallbackProvider
impl Sync for DefaultMetricsCallbackProvider
impl Unpin for DefaultMetricsCallbackProvider
impl UnwindSafe for DefaultMetricsCallbackProvider